@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.2.4   2019/08/20
+ * Version: 0.2.5   2019/12/25
  */
 
 #include "caitsith.h"
@@ -1170,9 +1170,6 @@ int cs_open_permission(const struct path *path, const int flag)
 	if (d_is_dir(path->dentry))
 		return 0;
 #endif
-	/* Sockets can't be opened by open(). */
-	if (S_ISSOCK(d_inode(path->dentry)->i_mode))
-		return 0;
 	r.obj.path[0] = *path;
 	if (!(cs_flags & CS_TASK_IS_IN_EXECVE))
 		cs_check_auto_domain_transition();
@@ -1530,9 +1527,6 @@ int cs_unlink_permission(const struct path *path)
  */
 int cs_getattr_permission(const struct path *path)
 {
-	/* It is not safe to call cs_get_socket_name(). */
-	if (S_ISSOCK(d_inode(path->dentry)->i_mode))
-		return 0;
 	return cs_path_perm(CS_MAC_GETATTR, path);
 }
 
