@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.2.4   2019/08/20
+ * Version: 0.2.5   2019/12/25
  */
 
 #include "caitsith.h"
@@ -15,8 +15,6 @@
 
 /***** SECTION1: Constants definition *****/
 
-#define SOCKFS_MAGIC 0x534F434B
-
 /***** SECTION2: Structure definition *****/
 
 /***** SECTION3: Prototype definition section *****/
@@ -27,8 +25,6 @@ static char *cs_get_dentry_path(struct dentry *dentry, char * const buffer,
 				const int buflen);
 static char *cs_get_local_path(struct dentry *dentry, char * const buffer,
 			       const int buflen);
-static char *cs_get_socket_name(const struct path *path, char * const buffer,
-				const int buflen);
 static int cs_const_part_length(const char *filename);
 
 /***** SECTION4: Standalone functions section *****/
@@ -393,32 +389,6 @@ out:
 	return ERR_PTR(-ENOMEM);
 }
 
-/**
- * cs_get_socket_name - Get the name of a socket.
- *
- * @path:   Pointer to "struct path".
- * @buffer: Pointer to buffer to return value in.
- * @buflen: Sizeof @buffer.
- *
- * Returns the buffer.
- */
-static char *cs_get_socket_name(const struct path *path, char * const buffer,
-				const int buflen)
-{
-	struct inode *inode = d_backing_inode(path->dentry);
-	struct socket *sock = inode ? SOCKET_I(inode) : NULL;
-	struct sock *sk = sock ? sock->sk : NULL;
-
-	if (sk) {
-		snprintf(buffer, buflen,
-			 "socket:[family=%u:type=%u:protocol=%u]",
-			 sk->sk_family, sk->sk_type, sk->sk_protocol);
-	} else {
-		snprintf(buffer, buflen, "socket:[unknown]");
-	}
-	return buffer;
-}
-
 /**
  * cs_realpath - Returns realpath(3) of the given pathname but ignores chroot'ed root.
  *
@@ -451,12 +421,7 @@ char *cs_realpath(const struct path *path)
 			break;
 		/* To make sure that pos is '\0' terminated. */
 		buf[buf_len - 1] = '\0';
-		/* Get better name for socket. */
-		if (sb->s_magic == SOCKFS_MAGIC) {
-			pos = cs_get_socket_name(path, buf, buf_len - 1);
-			goto encode;
-		}
-		/* For "pipe:[\$]". */
+		/* For "pipe:[\$]" and "socket:[\$]". */
 		if (dentry->d_op && dentry->d_op->d_dname) {
 			pos = dentry->d_op->d_dname(dentry, buf, buf_len - 1);
 			goto encode;
